==> zellij-0.40.1.tar.gz: zellij-0.40.1/zellij-utils/src/plugin_api/plugin_permission.rs <==
pub use super::generated_api::api::plugin_permission::PermissionType as ProtobufPermissionType;
use crate::data::PermissionType;

use std::convert::TryFrom;

impl TryFrom<ProtobufPermissionType> for PermissionType {
    type Error = &'static str;
    fn try_from(protobuf_permission: ProtobufPermissionType) -> Result<Self, &'static str> {
        match protobuf_permission {
            ProtobufPermissionType::ReadApplicationState => {
                Ok(PermissionType::ReadApplicationState)
            },
            ProtobufPermissionType::ChangeApplicationState => {
                Ok(PermissionType::ChangeApplicationState)
            },
            ProtobufPermissionType::OpenFiles => Ok(PermissionType::OpenFiles),
            ProtobufPermissionType::RunCommands => Ok(PermissionType::RunCommands),
            ProtobufPermissionType::OpenTerminalsOrPlugins => {
                Ok(PermissionType::OpenTerminalsOrPlugins)
            },
            ProtobufPermissionType::WriteToStdin => Ok(PermissionType::WriteToStdin),
            ProtobufPermissionType::WebAccess => Ok(PermissionType::WebAccess),
            ProtobufPermissionType::ReadCliPipes => Ok(PermissionType::ReadCliPipes),
            ProtobufPermissionType::MessageAndLaunchOtherPlugins => {
                Ok(PermissionType::MessageAndLaunchOtherPlugins)
            },
        }
    }
}

impl TryFrom<PermissionType> for ProtobufPermissionType {
    type Error = &'static str;
    fn try_from(permission: PermissionType) -> Result<Self, &'static str> {
        match permission {
            PermissionType::ReadApplicationState => {
                Ok(ProtobufPermissionType::ReadApplicationState)
            },
            PermissionType::ChangeApplicationState => {
                Ok(ProtobufPermissionType::ChangeApplicationState)
            },
            PermissionType::OpenFiles => Ok(ProtobufPermissionType::OpenFiles),
            PermissionType::RunCommands => Ok(ProtobufPermissionType::RunCommands),
            PermissionType::OpenTerminalsOrPlugins => {
                Ok(ProtobufPermissionType::OpenTerminalsOrPlugins)
            },
            PermissionType::WriteToStdin => Ok(ProtobufPermissionType::WriteToStdin),
            PermissionType::WebAccess => Ok(ProtobufPermissionType::WebAccess),
            PermissionType::ReadCliPipes => Ok(ProtobufPermissionType::ReadCliPipes),
            PermissionType::MessageAndLaunchOtherPlugins => {
                Ok(ProtobufPermissionType::MessageAndLaunchOtherPlugins)
            },
        }
    }
}

==> zellij-0.41.2.tar.gz: zellij-0.41.2/zellij-utils/src/plugin_api/plugin_permission.rs <==
pub use super::generated_api::api::plugin_permission::PermissionType as ProtobufPermissionType;
use crate::data::PermissionType;

use std::convert::TryFrom;

impl TryFrom<ProtobufPermissionType> for PermissionType {
    type Error = &'static str;
    fn try_from(protobuf_permission: ProtobufPermissionType) -> Result<Self, &'static str> {
        match protobuf_permission {
            ProtobufPermissionType::ReadApplicationState => {
                Ok(PermissionType::ReadApplicationState)
            },
            ProtobufPermissionType::ChangeApplicationState => {
                Ok(PermissionType::ChangeApplicationState)
            },
            ProtobufPermissionType::OpenFiles => Ok(PermissionType::OpenFiles),
            ProtobufPermissionType::RunCommands => Ok(PermissionType::RunCommands),
            ProtobufPermissionType::OpenTerminalsOrPlugins => {
                Ok(PermissionType::OpenTerminalsOrPlugins)
            },
            ProtobufPermissionType::WriteToStdin => Ok(PermissionType::WriteToStdin),
            ProtobufPermissionType::WebAccess => Ok(PermissionType::WebAccess),
            ProtobufPermissionType::ReadCliPipes => Ok(PermissionType::ReadCliPipes),
            ProtobufPermissionType::MessageAndLaunchOtherPlugins => {
                Ok(PermissionType::MessageAndLaunchOtherPlugins)
            },
            ProtobufPermissionType::Reconfigure => Ok(PermissionType::Reconfigure),
        }
    }
}

impl TryFrom<PermissionType> for ProtobufPermissionType {
    type Error = &'static str;
    fn try_from(permission: PermissionType) -> Result<Self, &'static str> {
        match permission {
            PermissionType::ReadApplicationState => {
                Ok(ProtobufPermissionType::ReadApplicationState)
            },
            PermissionType::ChangeApplicationState => {
                Ok(ProtobufPermissionType::ChangeApplicationState)
            },
            PermissionType::OpenFiles => Ok(ProtobufPermissionType::OpenFiles),
            PermissionType::RunCommands => Ok(ProtobufPermissionType::RunCommands),
            PermissionType::OpenTerminalsOrPlugins => {
                Ok(ProtobufPermissionType::OpenTerminalsOrPlugins)
            },
            PermissionType::WriteToStdin => Ok(ProtobufPermissionType::WriteToStdin),
            PermissionType::WebAccess => Ok(ProtobufPermissionType::WebAccess),
            PermissionType::ReadCliPipes => Ok(ProtobufPermissionType::ReadCliPipes),
            PermissionType::MessageAndLaunchOtherPlugins => {
                Ok(ProtobufPermissionType::MessageAndLaunchOtherPlugins)
            },
            PermissionType::Reconfigure => Ok(ProtobufPermissionType::Reconfigure),
        }
    }
}
